Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(32)

Unified Diff: ash/system/brightness/tray_brightness_unittest.cc

Issue 2909763002: Revert of Rename MaximizeMode to TabletMode (Closed)
Patch Set: Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/system/brightness/tray_brightness.cc ('k') | ash/system/overview/overview_button_tray.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/system/brightness/tray_brightness_unittest.cc
diff --git a/ash/system/brightness/tray_brightness_unittest.cc b/ash/system/brightness/tray_brightness_unittest.cc
index 3ae39da4ea7514c1ec8832021b9578335e65e9b6..e1f4e086285dc9396e958d6601b096b4d40fcadb 100644
--- a/ash/system/brightness/tray_brightness_unittest.cc
+++ b/ash/system/brightness/tray_brightness_unittest.cc
@@ -10,7 +10,7 @@
#include "ash/system/tray/system_tray_delegate.h"
#include "ash/system/tray/system_tray_item.h"
#include "ash/test/ash_test_base.h"
-#include "ash/wm/tablet_mode/tablet_mode_controller.h"
+#include "ash/wm/maximize_mode/maximize_mode_controller.h"
#include "ui/views/view.h"
namespace ash {
@@ -44,22 +44,26 @@
EXPECT_FALSE(tray->visible());
}
// Tests the construction of the default view while TabletMode is active.
// The BrightnessView should be visible.
-TEST_F(TrayBrightnessTest, CreateDefaultViewDuringTabletMode) {
- Shell::Get()->tablet_mode_controller()->EnableTabletModeWindowManager(true);
+TEST_F(TrayBrightnessTest, CreateDefaultViewDuringMaximizeMode) {
+ Shell::Get()->maximize_mode_controller()->EnableMaximizeModeWindowManager(
+ true);
std::unique_ptr<views::View> tray(CreateDefaultView());
EXPECT_TRUE(tray->visible());
- Shell::Get()->tablet_mode_controller()->EnableTabletModeWindowManager(false);
+ Shell::Get()->maximize_mode_controller()->EnableMaximizeModeWindowManager(
+ false);
}
// Tests that the enabling of TabletMode affects a previously created
// BrightnessView, changing the visibility.
-TEST_F(TrayBrightnessTest, DefaultViewVisibilityChangesDuringTabletMode) {
+TEST_F(TrayBrightnessTest, DefaultViewVisibilityChangesDuringMaximizeMode) {
std::unique_ptr<views::View> tray(CreateDefaultView());
- Shell::Get()->tablet_mode_controller()->EnableTabletModeWindowManager(true);
+ Shell::Get()->maximize_mode_controller()->EnableMaximizeModeWindowManager(
+ true);
EXPECT_TRUE(tray->visible());
- Shell::Get()->tablet_mode_controller()->EnableTabletModeWindowManager(false);
+ Shell::Get()->maximize_mode_controller()->EnableMaximizeModeWindowManager(
+ false);
EXPECT_FALSE(tray->visible());
}
@@ -70,22 +74,26 @@
EXPECT_TRUE(tray->visible());
}
// Tests that when the detailed view is created during TabletMode that its
// BrightnessView is visible.
-TEST_F(TrayBrightnessTest, CreateDetailedViewDuringTabletMode) {
- Shell::Get()->tablet_mode_controller()->EnableTabletModeWindowManager(true);
+TEST_F(TrayBrightnessTest, CreateDetailedViewDuringMaximizeMode) {
+ Shell::Get()->maximize_mode_controller()->EnableMaximizeModeWindowManager(
+ true);
std::unique_ptr<views::View> tray(CreateDetailedView());
EXPECT_TRUE(tray->visible());
- Shell::Get()->tablet_mode_controller()->EnableTabletModeWindowManager(false);
+ Shell::Get()->maximize_mode_controller()->EnableMaximizeModeWindowManager(
+ false);
}
// Tests that the enabling of TabletMode has no affect on the visibility of a
// previously created BrightnessView that belongs to a detailed view.
-TEST_F(TrayBrightnessTest, DetailedViewVisibilityChangesDuringTabletMode) {
+TEST_F(TrayBrightnessTest, DetailedViewVisibilityChangesDuringMaximizeMode) {
std::unique_ptr<views::View> tray(CreateDetailedView());
- Shell::Get()->tablet_mode_controller()->EnableTabletModeWindowManager(true);
+ Shell::Get()->maximize_mode_controller()->EnableMaximizeModeWindowManager(
+ true);
EXPECT_TRUE(tray->visible());
- Shell::Get()->tablet_mode_controller()->EnableTabletModeWindowManager(false);
+ Shell::Get()->maximize_mode_controller()->EnableMaximizeModeWindowManager(
+ false);
EXPECT_TRUE(tray->visible());
}
« no previous file with comments | « ash/system/brightness/tray_brightness.cc ('k') | ash/system/overview/overview_button_tray.h » ('j') | no next file with comments »
@@ -44,22 +44,26 @@
EXPECT_FALSE(tray->visible());
}
-// Tests the construction of the default view while TabletMode is active.
+// Tests the construction of the default view while MaximizeMode is active.
// The BrightnessView should be visible.
@@ -44,22 +44,26 @@
}
-// Tests that the enabling of TabletMode affects a previously created
+// Tests that the enabling of MaximizeMode affects a previously created
// BrightnessView, changing the visibility.
@@ -70,22 +74,26 @@
EXPECT_TRUE(tray->visible());
}
-// Tests that when the detailed view is created during TabletMode that its
+// Tests that when the detailed view is created during MaximizeMode that its
// BrightnessView is visible.
@@ -70,22 +74,26 @@
}
-// Tests that the enabling of TabletMode has no affect on the visibility of a
+// Tests that the enabling of MaximizeMode has no affect on the visibility of a
// previously created BrightnessView that belongs to a detailed view.

Powered by Google App Engine
This is Rietveld 408576698